@@ -121,7 +121,7 @@ class Speaker(caching.base.CachingMixin,models.Model):
             return self.AvgSpeakingRate
         words = WordToken.objects.filter(Dialog__Speaker=self).filter(Category__CategoryType__in = ['Content','Function','Function_Content','Function_Function'])
         dur = sum([x.getDuration() for x in words])
-        sylls = sum([x.isSyllabic() for y in words for x in y.SR.all() if x.isSyllabic()])
+        sylls = sum([x.get_syllable_count() for x in words])
         self.AvgSpeakingRate = float(sylls)/float(dur)
         self.save()
         return self.AvgSpeakingRate
@@ -856,7 +856,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
         return diagPlace
 
     def get_syllable_count(self):
-        return sum([x.isSyllabic for x in self.SR.all()])
+        return sum([x.isSyllabic() for x in self.SR.all()])
 
     def getDuration(self):
         return self.End - self.Begin
